@@ -11,12 +11,12 @@
 #' @return pooled SDs for groups and across groups
 #'
 colwise_pool <- function(data, n1, n2, m1, m2, sd1, sd2) {
-  n1 <- data[, "n.1"]
-  n2 <- data[, "n.2"]
-  m1 <- data[, "m.1"]
-  m2 <- data[, "m.2"]
-  sd1 <- data[, "sd.1"]
-  sd2 <- data[, "sd.2"]
+  n1 <- data[, n1]
+  n2 <- data[, n2]
+  m1 <- data[, m1]
+  m2 <- data[, m2]
+  sd1 <- data[, sd1]
+  sd2 <- data[, sd2]
 
   numerator1 <- (n1 - 1) * sd1^2
   numerator2 <- (n2 - 1) * sd2^2
